Setup server for mobile device communication
This module implements a simple TCP server that waits for mobile devices to send certificate messages and network key messages during the node initialization process.
Structs
- Setup
Data - Complete setup data received from mobile device
- Setup
Server